@@ -1,7 +1,8 @@
 ##NCA
 NCA<-function(Totalplot,Dose, ref_data, test_data, SingleRdata, SingleRdata1,
                SingleTdata,SingleTdata1,xaxis, yaxis,rdata.split,tdata.split,
-               Demo=FALSE,BANOVA=FALSE,replicated=FALSE,MIX=FALSE, parallel=FALSE)
+               Tau, TlastD,SingleRdata0,SingleTdata0,
+               Demo=FALSE,BANOVA=FALSE,replicated=FALSE,MIX=FALSE, parallel=FALSE, multiple=FALSE)
 {
 
 #fitting data with linear regression model
@@ -44,6 +45,7 @@ if(replicated){
  
   #calculate AUC
  CmaxRef<-0
+ CminRef<-0
  AUCINFRef<-0
  AUCTRef<-0
  TmaxRef<-0
@@ -52,7 +54,8 @@ if(replicated){
  VdFRef<-0
  KelRef<-0
  ClFRef<-0
-
+ CavRef<-0
+ FluRef<-0
       for (j in 1:length(R.split)){
          #if subject of W.split==subject of kepar, then use ke of kepar to claculate AUC(0~INF)
           
@@ -91,16 +94,24 @@ if(replicated){
           auc_ref <-0
           tmax_ref<-0
           Cmax_ref<-0
+          Cmin_ref<-0
           aumc_ref<-0
           for(i in 2:length(R.split[[j]][["time"]])){
              #calculate AUC and exclude AUC==NA (auc<-0)
              auc_ref[i]<-(R.split[[j]][["time"]][i]-R.split[[j]][["time"]][i-1])*(R.split[[j]][["conc"]][i]+R.split[[j]][["conc"]][i-1])* 0.5
              auc_ref[i]<-auc_ref[i]+auc_ref[i-1]
              #calculate AUMC
-             aumc_ref[i]<-((R.split[[j]][["time"]][i])*(R.split[[j]][["conc"]][i])+(R.split[[j]][["time"]][i-1])*(R.split[[j]][["conc"]][i-1]))*
+             if(multiple){
+                aumc_ref[i]<-((R.split[[j]][["time"]][i]-TlastD)*(R.split[[j]][["conc"]][i])+(R.split[[j]][["time"]][i-1]-TlastD)*(R.split[[j]][["conc"]][i-1]))*
+                          ((R.split[[j]][["time"]][i]-TlastD)-(R.split[[j]][["time"]][i-1]-TlastD))* 0.5
+               }
+             else{
+                aumc_ref[i]<-((R.split[[j]][["time"]][i])*(R.split[[j]][["conc"]][i])+(R.split[[j]][["time"]][i-1])*(R.split[[j]][["conc"]][i-1]))*
                           ((R.split[[j]][["time"]][i])-(R.split[[j]][["time"]][i-1]))* 0.5
+               }
              aumc_ref[i]<-aumc_ref[i]+aumc_ref[i-1]
              Cmax_ref<-max(R.split[[j]][["conc"]], na.rm = FALSE)
+             Cmin_ref<-min(R.split[[j]][["conc"]], na.rm = FALSE)
              subgr= c(Cmax_ref)
              tmax_ref<-R.split[[j]][R.split[[j]][["conc"]] %in% subgr,]
               }
@@ -110,20 +121,36 @@ if(replicated){
                aucINF<-auc_ref[length(R.split[[j]][["conc"]])]+auc.infinity
 
                 #calculate AUMC (0~INF)
+                  if(multiple){
+                  aumc.infinity_1<-(R.split[[j]][["conc"]][length(R.split[[j]][["conc"]])])*(R.split[[j]][["time"]][length(R.split[[j]][["time"]])]-TlastD)/ke
+                  }
+                  else{
                   aumc.infinity_1<-(R.split[[j]][["conc"]][length(R.split[[j]][["conc"]])])*(R.split[[j]][["time"]][length(R.split[[j]][["time"]])])/ke
+                  }
                   aumc.infinity_2<-(R.split[[j]][["conc"]][length(R.split[[j]][["conc"]])]/(ke^2))
                   aumcINF<-aumc_ref[length(R.split[[j]][["conc"]])]+aumc.infinity_1+aumc.infinity_2
 
                    #for summary result
                   CmaxRef[j]<-Cmax_ref
+                  CminRef[j]<-Cmin_ref
                   AUCINFRef[j]<-aucINF
                   AUCTRef[j]<-auc_ref[length(R.split[[j]][["conc"]])]
                   TmaxRef[j]<-tmax_ref$time #revised: tmax_ref[,5]
-                  MRTINFRef[j]<-aumcINF/aucINF
                   T12Ref[j]<-log(2)/ke
-                  VdFRef[j]<-Dose/(aucINF*ke)
                   KelRef[j]<-ke
-                  ClFRef[j]<-Dose/aucINF
+                 
+                  if(multiple){
+                       VdFRef[j]<-Dose/((auc_ref[length(R.split[[j]][["conc"]])])*ke)
+                       ClFRef[j]<-Dose/(auc_ref[length(R.split[[j]][["conc"]])])
+                       MRTINFRef[j]<-(aumc_ref[length(R.split[[j]][["conc"]])])/(auc_ref[length(R.split[[j]][["conc"]])])
+                       CavRef[j]<-(auc_ref[length(R.split[[j]][["conc"]])])/Tau
+                       FluRef[j]<-((Cmax_ref-Cmin_ref)/((auc_ref[length(R.split[[j]][["conc"]])])/Tau))*100
+                      }
+                      else{
+                       VdFRef[j]<-Dose/(aucINF*ke)
+                       ClFRef[j]<-Dose/aucINF
+                       MRTINFRef[j]<-aumcINF/aucINF 
+                      }
 
                  cat("\n")
                  if(replicated){
@@ -134,7 +161,12 @@ if(replicated){
                     }
                  cat("--------------------------------------------------------------------------\n")
                  output<-data.frame(R.split[[j]][["subj"]],R.split[[j]][["time"]],R.split[[j]][["conc"]],formatC(auc_ref,format="f",digits=3),formatC(aumc_ref,format="f",digits=3))
-                 colnames(output)<-list("subj","time","conc", "AUC(0-t)","AUMC(0-t)")
+                  if(multiple){
+                  colnames(output)<-list("subj","time","conc", "AUC(tau)ss","AUMC(tau)ss")
+                  }
+                  else{
+                  colnames(output)<-list("subj","time","conc", "AUC(0-t)","AUMC(0-t)")
+                  }
                  show(output)
 
               cat("\n<<Selected data points for lambda_z estimation>>\n")
@@ -143,6 +175,25 @@ if(replicated){
               
               cat("\n<<Final PK Parameters>>\n")
               cat("----------------------------\n")
+              if(multiple){
+              cat("           R sq. =",R_sq ,"\n")
+              cat("Adj. R sq. (ARS) =",AR_sq ,"\n")
+              cat("        lambda_z =",ke ,"\n")
+              cat("         Cmax_ss =",Cmax_ref ,"\n")
+              cat("         Cmin_ss =",Cmin_ref ,"\n")
+              cat("         Tmax_ss =",TmaxRef[j] ,"\n")
+              cat("             Cav =",(auc_ref[length(R.split[[j]][["conc"]])])/Tau ,"\n")
+              cat("    Fluctuation% =",((Cmax_ref-Cmin_ref)/((auc_ref[length(R.split[[j]][["conc"]])])/Tau))*100 ,"\n")
+              cat("            Cl/F =",Dose/(auc_ref[length(R.split[[j]][["conc"]])]),"\n")
+              cat("            Vd/F =",Dose/((auc_ref[length(R.split[[j]][["conc"]])])*ke),"\n")
+              cat("         T1/2(z) =",log(2)/ke,"\n")
+              cat("      AUC(tau)ss =",auc_ref[length(R.split[[j]][["conc"]])],"\n")
+              cat("     AUMC(tau)ss =",aumc_ref[length(R.split[[j]][["conc"]])],"\n")
+              cat("             MRT =",(aumc_ref[length(R.split[[j]][["conc"]])])/(auc_ref[length(R.split[[j]][["conc"]])]),"\n")
+              cat("--------------------------------------------------------------------------\n")
+              cat("\n\n")
+                }
+              else{
               cat("           R sq. =",R_sq ,"\n")
               cat("Adj. R sq. (ARS) =",AR_sq ,"\n")
               cat("        lambda_z =",ke ,"\n")
@@ -159,6 +210,7 @@ if(replicated){
               cat("      MRT(0-inf) =",aumcINF/aucINF,"\n")
               cat("--------------------------------------------------------------------------\n")
               cat("\n\n")
+             }
   }
 ################################################################# Test linear regression
 #split dataframe into sub-dataframe by subject for test data
@@ -198,6 +250,7 @@ if(replicated){
 
   #calculate AUC
 CmaxTest<-0
+CminTest<-0
 AUCINFTest<-0
 AUCTTest<-0
 TmaxTest<-0
@@ -206,6 +259,8 @@ T12Test<-0
 VdFTest<-0
 KelTest<-0
 ClFTest<-0
+CavTest<-0
+FluTest<-0
       for (j in 1:length(T.split)){
          #if subject of W.split==subject of kepar, then use ke of kepar to claculate AUC(0~INF)
           
@@ -244,6 +299,7 @@ ClFTest<-0
                
           auc_test <-0
           Cmax_test<-0
+          Cmin_test<-0
           tmax_test<-0
           aumc_test<-0
 
@@ -252,10 +308,17 @@ ClFTest<-0
              auc_test[i]<-(T.split[[j]][["time"]][i]-T.split[[j]][["time"]][i-1])*(T.split[[j]][["conc"]][i]+T.split[[j]][["conc"]][i-1])* 0.5
              auc_test[i]<-auc_test[i]+auc_test[i-1]
              #calculate AUMC
+             if(multiple){
+             aumc_test[i]<-((T.split[[j]][["time"]][i]-TlastD)*(T.split[[j]][["conc"]][i])+(T.split[[j]][["time"]][i-1]-TlastD)*(T.split[[j]][["conc"]][i-1]))*
+                          ((T.split[[j]][["time"]][i]-TlastD)-(T.split[[j]][["time"]][i-1]-TlastD))* 0.5
+              }
+             else{
              aumc_test[i]<-((T.split[[j]][["time"]][i])*(T.split[[j]][["conc"]][i])+(T.split[[j]][["time"]][i-1])*(T.split[[j]][["conc"]][i-1]))*
                           ((T.split[[j]][["time"]][i])-(T.split[[j]][["time"]][i-1]))* 0.5
+              } 
              aumc_test[i]<-aumc_test[i]+aumc_test[i-1]
              Cmax_test<-max(T.split[[j]][["conc"]], na.rm = FALSE)
+             Cmin_test<-min(T.split[[j]][["conc"]], na.rm = FALSE)
              subgr= c(Cmax_test)
              tmax_test<-T.split[[j]][T.split[[j]][["conc"]] %in% subgr,]
               }
@@ -265,21 +328,36 @@ ClFTest<-0
                aucINF<-auc_test[length(T.split[[j]][["conc"]])]+auc.infinity
 
                 #calculate AUMC (0~INF)
-                  aumc.infinity_1<-(T.split[[j]][["conc"]][length(T.split[[j]][["conc"]])])*(T.split[[j]][["time"]][length(T.split[[j]][["time"]])])/ke1
+                   if(multiple){
+                   aumc.infinity_1<-(T.split[[j]][["conc"]][length(T.split[[j]][["conc"]])])*(T.split[[j]][["time"]][length(T.split[[j]][["time"]])]-TlastD)/ke1
+                   }
+                   else{
+                   aumc.infinity_1<-(T.split[[j]][["conc"]][length(T.split[[j]][["conc"]])])*(T.split[[j]][["time"]][length(T.split[[j]][["time"]])])/ke1
+                   }
                   aumc.infinity_2<-(T.split[[j]][["conc"]][length(T.split[[j]][["conc"]])]/(ke1^2))
                   aumcINF<-aumc_test[length(T.split[[j]][["conc"]])]+aumc.infinity_1+aumc.infinity_2
 
                   #for summary result
                   CmaxTest[j]<-Cmax_test
+                  CminTest[j]<-Cmin_test
                   AUCINFTest[j]<-aucINF
                   AUCTTest[j]<-auc_test[length(T.split[[j]][["conc"]])]
                   TmaxTest[j]<-tmax_test$time
-                  MRTINFTest[j]<-aumcINF/aucINF
                   T12Test[j]<-log(2)/ke1
-                  VdFTest[j]<-Dose/(aucINF*ke1)
                   KelTest[j]<-ke1
+                 
+                       if(multiple){
+                  VdFTest[j]<-Dose/((auc_test[length(T.split[[j]][["conc"]])])*ke1)
+                  ClFTest[j]<-Dose/(auc_test[length(T.split[[j]][["conc"]])])
+                  MRTINFTest[j]<-(aumc_test[length(T.split[[j]][["conc"]])])/(auc_test[length(T.split[[j]][["conc"]])])
+                  CavTest[j]<-(auc_test[length(T.split[[j]][["conc"]])])/Tau
+                  FluTest[j]<-((Cmax_test-Cmin_test)/((auc_test[length(T.split[[j]][["conc"]])])/Tau))*100
+                    }
+                    else{
+                  VdFTest[j]<-Dose/(aucINF*ke1)
                   ClFTest[j]<-Dose/aucINF
-
+                  MRTINFTest[j]<-aumcINF/aucINF     
+                        }
                  cat("\n")
                  if(replicated){
                  cat("<< NCA Outputs:- Subj.#",su1,", Seq",se1,", Prd",pr1," (Test)>>\n")
@@ -289,7 +367,12 @@ ClFTest<-0
                     }
                  cat("--------------------------------------------------------------------------\n")
                  output<-data.frame(T.split[[j]][["subj"]],T.split[[j]][["time"]],T.split[[j]][["conc"]],formatC(auc_test,format="f",digits=3),formatC(aumc_test,format="f",digits=3) )
-                 colnames(output)<-list("subj","time","conc", "AUC(0-t)","AUMC(0-t)")
+                  if(multiple){
+                  colnames(output)<-list("subj","time","conc", "AUC(tau)ss","AUMC(tau)ss")
+                  }
+                  else{
+                  colnames(output)<-list("subj","time","conc", "AUC(0-t)","AUMC(0-t)")
+                  }
                  show(output)
 
               cat("\n<<Selected data points for lambda_z estimation>>\n")
@@ -298,6 +381,25 @@ ClFTest<-0
               
               cat("\n<<Final PK Parameters>>\n")
               cat("----------------------------\n")
+              if(multiple){
+              cat("           R sq. =",R_sq1 ,"\n")
+              cat("Adj. R sq. (ARS) =",AR_sq1 ,"\n")
+              cat("        lambda_z =",ke1 ,"\n")
+              cat("         Cmax_ss =",Cmax_test ,"\n")
+              cat("         Cmin_ss =",Cmin_test ,"\n")
+              cat("         Tmax_ss =",TmaxTest[j] ,"\n")
+              cat("             Cav =",(auc_test[length(T.split[[j]][["conc"]])])/Tau ,"\n")
+              cat("    Fluctuation% =",((Cmax_test-Cmin_test)/((auc_test[length(T.split[[j]][["conc"]])])/Tau))*100 ,"\n")
+              cat("            Cl/F =",Dose/(auc_test[length(T.split[[j]][["conc"]])]),"\n")
+              cat("            Vd/F =",Dose/((auc_test[length(T.split[[j]][["conc"]])])*ke1),"\n")
+              cat("         T1/2(z) =",log(2)/ke1,"\n")
+              cat("      AUC(tau)ss =",auc_test[length(T.split[[j]][["conc"]])],"\n")
+              cat("     AUMC(tau)ss =",aumc_test[length(T.split[[j]][["conc"]])],"\n")
+              cat("             MRT =",(aumc_test[length(T.split[[j]][["conc"]])])/(auc_test[length(T.split[[j]][["conc"]])]),"\n")
+              cat("--------------------------------------------------------------------------\n")
+              cat("\n\n") 
+              }
+              else{  
               cat("           R sq. =",R_sq1 ,"\n")
               cat("Adj. R sq. (ARS) =",AR_sq1 ,"\n")
               cat("        lambda_z =",ke1 ,"\n")
@@ -314,6 +416,7 @@ ClFTest<-0
               cat("      MRT(0-inf) =",aumcINF/aucINF,"\n")
               cat("--------------------------------------------------------------------------\n")
               cat("\n\n")
+    }
   }
 
 
@@ -356,11 +459,20 @@ subjT<-0
      subjT[j]<-T.split[[j]][["subj"]][1]
      }
 if(parallel){
-description_Repdrugcode()
-sumindexR<-data.frame(subj=subjR,drug=c(1),Cmax=CmaxRef,AUC0t=AUCTRef,AUC0INF=AUCINFRef,
+ if(multiple){
+  description_Multipledrugcode() 
+  sumindexR<-data.frame(subj=subjR,drug=c(1),Cmax=CmaxRef,AUC0t=AUCTRef,Cmin=CminRef,
+                       Tmax=TmaxRef, MRTINF=MRTINFRef, T12=T12Ref, VdF=VdFRef, Kel=KelRef, ClF=ClFRef, Cav=CavRef, Flu=FluRef)
+  sumindexT<-data.frame(subj=subjT,drug=c(2),Cmax=CmaxTest,AUC0t=AUCTTest,Cmin=CminTest,
+                       Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest, Cav=CavTest, Flu=FluTest)
+  }
+  else{
+  description_Repdrugcode()
+  sumindexR<-data.frame(subj=subjR,drug=c(1),Cmax=CmaxRef,AUC0t=AUCTRef,AUC0INF=AUCINFRef,
                       Tmax=TmaxRef, MRTINF=MRTINFRef, T12=T12Ref, VdF=VdFRef, Kel=KelRef, ClF=ClFRef)
-sumindexT<-data.frame(subj=subjT,drug=c(2),Cmax=CmaxTest,AUC0t=AUCTTest,AUC0INF=AUCINFTest,
+  sumindexT<-data.frame(subj=subjT,drug=c(2),Cmax=CmaxTest,AUC0t=AUCTTest,AUC0INF=AUCINFTest,
                      Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest) 
+  }
 }
 else{
 seqR<-0
@@ -397,23 +509,44 @@ sumindexT<-data.frame(subj=subjT,drug=drugT,seq=seqT,prd=prdT,Cmax=CmaxTest,AUC0
    }
 else{
 
-description_drugcode()
-sumindexR<-data.frame(subj=subjR,drug=c(1),seq=seqR,prd=prdR,Cmax=CmaxRef,AUC0t=AUCTRef,AUC0INF=AUCINFRef,
-                      Tmax=TmaxRef, MRTINF=MRTINFRef, T12=T12Ref, VdF=VdFRef, Kel=KelRef, ClF=ClFRef)
-sumindexT<-data.frame(subj=subjT,drug=c(2),seq=seqT,prd=prdT,Cmax=CmaxTest,AUC0t=AUCTTest,AUC0INF=AUCINFTest,
-                     Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest)
- }
+if(multiple){
+   description_Multipledrugcode()
+   sumindexR<-data.frame(subj=subjR,drug=c(1),seq=seqR,prd=prdR,Cmax=CmaxRef,AUC0t=AUCTRef,Cmin=CminRef,
+                      Tmax=TmaxRef, MRTINF=MRTINFRef, T12=T12Ref, VdF=VdFRef, Kel=KelRef, ClF=ClFRef, Cav=CavRef, Flu=FluRef)
+   sumindexT<-data.frame(subj=subjT,drug=c(2),seq=seqT,prd=prdT,Cmax=CmaxTest,AUC0t=AUCTTest,Cmin=CminTest,
+                     Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest, Cav=CavTest, Flu=FluTest)
 }
+ else{ 
+ description_drugcode()
+ sumindexR<-data.frame(subj=subjR,drug=c(1),seq=seqR,prd=prdR,Cmax=CmaxRef,AUC0t=AUCTRef,AUC0INF=AUCINFRef,
+                      Tmax=TmaxRef, MRTINF=MRTINFRef, T12=T12Ref, VdF=VdFRef, Kel=KelRef, ClF=ClFRef)
+ sumindexT<-data.frame(subj=subjT,drug=c(2),seq=seqT,prd=prdT,Cmax=CmaxTest,AUC0t=AUCTTest,AUC0INF=AUCINFTest,
+                     Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest) 
+   }
+ }
+} 
 #########
 Total<-rbind(sumindexR,sumindexT)
 if(parallel){
-TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),Cmax=Total$Cmax, AUC0t=Total$AUC0t, AUC0INF=Total$AUC0INF,
+  if(multiple){
+   TotalData<-data.frame (subj=as.factor(Total$subj),drug=as.factor(Total$drug),Cmax_ss=Total$Cmax, AUCtau_ss=Total$AUC0t,
+                         lnCmax_ss=log(Total$Cmax),lnAUCtau_ss=log(Total$AUC0t))
+  }
+  else{
+   TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),Cmax=Total$Cmax, AUC0t=Total$AUC0t, AUC0INF=Total$AUC0INF,
                       lnCmax=log(Total$Cmax),lnAUC0t=log(Total$AUC0t),lnAUC0INF=log(Total$AUC0INF))
+   }
 }
 else{
-TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),seq=as.factor(Total$seq),
+if(multiple){
+  TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),seq=as.factor(Total$seq),
+                   prd=as.factor(Total$prd),Cmax_ss=Total$Cmax, AUCtau_ss=Total$AUC0t,lnCmax_ss=log(Total$Cmax),lnAUCtau_ss=log(Total$AUC0t))
+  }
+  else{
+   TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),seq=as.factor(Total$seq),
                    prd=as.factor(Total$prd),Cmax=Total$Cmax, AUC0t=Total$AUC0t, AUC0INF=Total$AUC0INF,
                    lnCmax=log(Total$Cmax),lnAUC0t=log(Total$AUC0t),lnAUC0INF=log(Total$AUC0INF))
+   }
 }
 show(TotalData)
 
@@ -424,15 +557,24 @@ show(TotalData)
 Totalplot<-Totalplot[ do.call(order, Totalplot) ,]
 s.split<-split(Totalplot,list(Totalplot$subj))
 if(parallel){
- Totalplot$conc[Totalplot$conc == 0] <- NA
- Totalplot <- na.omit(Totalplot)
- Totalplot.split<-split(Totalplot, list(Totalplot$subj))
+ if(multiple){
+    paraR.split<-split(SingleRdata1, list(SingleRdata1$subj))
+    paraT.split<-split(SingleTdata1, list(SingleTdata1$subj))
+    
+    RR.split<-split(SingleRdata0, list(SingleRdata0$subj))
+    TT.split<-split(SingleTdata0, list(SingleTdata0$subj))
+   }
+   else{
+    Totalplot$conc[Totalplot$conc == 0] <- NA
+    Totalplot <- na.omit(Totalplot)
+    Totalplot.split<-split(Totalplot, list(Totalplot$subj))
  
- Totalplotpara<-split( Totalplot, list(Totalplot$drug))
- paraR.split<-split( Totalplotpara[[1]], list(Totalplotpara[[1]]$subj))
- paraT.split<-split( Totalplotpara[[2]], list(Totalplotpara[[2]]$subj))
+    Totalplotpara<-split( Totalplot, list(Totalplot$drug))
+    paraR.split<-split( Totalplotpara[[1]], list(Totalplotpara[[1]]$subj))
+    paraT.split<-split( Totalplotpara[[2]], list(Totalplotpara[[2]]$subj))  
+     }
  }
- else{
+else{
  if(replicated){
      prdcount<-length(levels(TotalData$prd))
      LR<-data.frame(subj=Totalplot$subj,  seq=Totalplot$seq, prd=Totalplot$prd, drug=Totalplot$drug,
@@ -441,7 +583,21 @@ if(parallel){
      LR <- na.omit(LR)
      Ls.split<-split(LR, list(LR$subj))
         }
-    else{
+  else{
+    if(multiple){
+     LR<-data.frame(subj=SingleRdata0$subj, time=SingleRdata0$time,  conc=SingleRdata0$conc)
+     LR$conc[LR$conc == 0] <- NA
+     LR <- na.omit(LR)
+     LR.split<-split(LR, list(LR$subj))
+     
+     LT<-data.frame(subj=SingleTdata0$subj, time=SingleTdata0$time,  conc=SingleTdata0$conc)
+     LT$conc[LT$conc == 0] <- NA
+     LT <- na.omit(LT)
+     LT.split<-split(LT, list(LT$subj))
+         RR.split<-split(SingleRdata0, list(SingleRdata0$subj))
+         TT.split<-split(SingleTdata0, list(SingleTdata0$subj))
+    }
+      else{
     LR<-data.frame(subj=SingleRdata$subj, time=SingleRdata$time,  conc=SingleRdata$conc)
     LR$conc[LR$conc == 0] <- NA
     LR <- na.omit(LR)
@@ -451,6 +607,7 @@ if(parallel){
     LT$conc[LT$conc == 0] <- NA
     LT <- na.omit(LT)
     LT.split<-split(LT, list(LT$subj))
+      }
     }
  }
 windows(record = TRUE )
@@ -460,10 +617,20 @@ if(replicated){
    }
 else{ 
  if(parallel){
-    plotsingle.para(R.split, T.split, paraR.split,paraT.split,xaxis,yaxis )
+    if(multiple){
+       Multipleplotsingle.para(R.split,T.split,paraR.split,paraT.split,xaxis,yaxis,RR.split,TT.split,TlastD )
+       }
+      else{
+        plotsingle.para(R.split, T.split, paraR.split,paraT.split,xaxis,yaxis )
+      }
   }
   else{ 
-    plotsingle(LR.split,LT.split,R.split,T.split,xaxis,yaxis )
+     if(multiple){
+       Multipleplotsingle(LR.split,LT.split,RR.split,TT.split,xaxis,yaxis,TlastD )
+       }
+      else{
+        plotsingle(LR.split,LT.split,xaxis,yaxis,R.split,T.split )
+      }
   }
 }  
 ##export with txt file
@@ -493,6 +660,27 @@ if(replicated){
     }
  else{
    if(parallel){
+      if(multiple){
+        SingleRdata<-SingleRdata0
+        SingleTdata<-SingleTdata0
+        MultipleParaNCAoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData, rdata.split,tdata.split, Tau, TlastD)
+        MultipleParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
+          if (Demo){
+          #Demo=TRUE, BANOVA=FALSE
+          MultipleParamenu()
+          }
+           else {
+             if(MIX){
+            ##Demo=FALSE, BANOVA=TRUE
+             MultipleParaMIXanalyze(TotalData)
+                }
+             else{
+             #Demo=FALSE, BANOVA=FALSE
+             MultipleParaNCAsave(TotalData)
+               }
+             }
+        }
+      else{
       ParaNCAoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData,rdata.split ,tdata.split )
       ParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis) 
       if (Demo){
@@ -516,8 +704,31 @@ if(replicated){
            }
          }     
       }
+     } 
     else{
-      NCAoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData,rdata.split ,tdata.split )
+      if(multiple){
+        SingleRdata<-SingleRdata0
+        SingleTdata<-SingleTdata0
+        MultipleNCAoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData, Tau, TlastD,rdata.split,tdata.split )
+        MultipleNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
+          if (Demo){
+          #Demo=TRUE, BANOVA=FALSE
+          MultipleNCAmenu()
+          }
+           else {
+             if(BANOVA){
+            ##Demo=FALSE, BANOVA=TRUE
+             dev.off()
+             MultipleBANOVAanalyze(TotalData)
+                }
+             else{
+             #Demo=FALSE, BANOVA=FALSE
+             MultipleNCAsave(TotalData)
+               }
+             }
+        }
+      else{
+      NCAoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData,rdata.split,tdata.split )
       NCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
        
        if (Demo){
@@ -540,11 +751,13 @@ if(replicated){
           else{
          #Demo=FALSE, BANOVA=FALSE
          NCAsave(TotalData)
-           }
-         }     
-      }
+           
+          }
+        }     
+     }
    }
-} 
+ }
+}  
 
 
  
\ No newline at end of file
