@@ -1,7 +1,7 @@
 description_import<-function(){
    cat("\n\n")
    filepath<-getwd()
-   cat("R will import your data file from the directory of \n")
+   cat("Bear will load your data file from the directory of \n")
    cat("",filepath,".\n")
    cat("\n")
    cat("\nEnter the file name (** Please NO file extention! **):\n")
